contextService property
Optional codebase context service used to assemble the prompt context.
Tests can pass null to skip context generation.
Implementation
final CodebaseContextService? contextService;
Optional codebase context service used to assemble the prompt context.
Tests can pass null to skip context generation.
final CodebaseContextService? contextService;