PromptRenderer class

Renders a workflow prompt template for one issue attempt.

Supports a small Liquid-compatible subset that's sufficient for Symphony templates:

  • {{ var.path }} interpolation.
  • {% if expr %} ... {% else %} ... {% endif %} conditionals using variable truthiness.
  • {% for item in collection %} ... {% endfor %} iteration over lists.

Strict rules:

Constructors

PromptRenderer()
Creates a prompt renderer.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(String template, {required Issue issue, int? attempt}) String
Renders template using issue and attempt.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited