RunnerEvent class sealed

Sealed runtime event emitted by an AgentRunner.

Implementers

Properties

at DateTime
Timestamp when the event was emitted.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Optional human-readable summary.
final
name String
Stable enum-like name for logging and snapshots.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON view used by the snapshot/dashboard.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited