RunnerTokenUsage class

Token-usage payload reported by the runner.

Constructors

RunnerTokenUsage({int inputTokens = 0, int outputTokens = 0, int totalTokens = 0})
Creates a token usage value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTokens int
Input/prompt tokens.
final
outputTokens int
Output/completion tokens.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokens int
Total tokens (input + output).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON view of the payload.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited