TokenUsageUpdated class

Emitted when token usage is updated for the current turn.

Inheritance

Constructors

TokenUsageUpdated({required RunnerTokenUsage usage, DateTime? at, String? message})
Creates the event.

Properties

at DateTime
Timestamp when the event was emitted.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
Optional human-readable summary.
finalinherited
name String
Stable enum-like name for logging and snapshots.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage RunnerTokenUsage
Latest token usage snapshot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON view used by the snapshot/dashboard.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited