IssueBlocker class

Reference to an issue that blocks another issue.

Constructors

IssueBlocker({String? id, String? identifier, String? state})
Creates a blocker reference.
const
IssueBlocker.fromJson(Map<String, dynamic> json)
Builds a blocker from a JSON-style map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Tracker-internal id, when known.
final
identifier String?
Human-readable identifier, when known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Current state of the blocker, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the blocker.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited