TrackerError<T> class

Failed tracker result.

Inheritance

Constructors

TrackerError(TrackerFailure failure)
Creates a failed result.
const

Properties

failure TrackerFailure
Underlying failure.
final
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
Returns true when the result is a TrackerError.
no setterinherited
isSuccess bool
Returns true when the result is a TrackerSuccess.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fold<R>(R onFailure(TrackerFailure failure), R onSuccess(T value)) → R
Folds the result into a single value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited