TrackerFailure class
Failure value returned by tracker adapters.
Constructors
- TrackerFailure(TrackerFailureCode code, String message, {Object? cause})
-
Creates a tracker failure.
const
Properties
- cause → Object?
-
Underlying error, if any.
final
- code → TrackerFailureCode
-
Categorized failure code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable failure message for logs and dashboards.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited