TrackerResult<T> class
sealed
Result wrapper used by tracker operations.
This is intentionally a small, explicit Either rather than pulling in the
dartz package. Use fold to handle both arms.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
Returns true when the result is a TrackerError.
no setter
- isSuccess → bool
-
Returns true when the result is a TrackerSuccess.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fold<
R> (R onFailure(TrackerFailure failure), R onSuccess(T value)) → R - Folds the result into a single value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited