CodexWorkflowConfig class

Coding-agent subprocess config.

Constructors

CodexWorkflowConfig({required String command, required String? approvalPolicy, required String? threadSandbox, required String? turnSandboxPolicy, required Duration turnTimeout, required Duration readTimeout, required Duration stallTimeout})
Creates Codex workflow config.
const
CodexWorkflowConfig.fromMap(Map<String, dynamic> map)
Builds Codex config from a map.
factory

Properties

approvalPolicy String?
Approval policy passed through to the runner.
final
command String
Shell command used to launch the app-server.
final
hashCode int
The hash code for this object.
no setterinherited
readTimeout Duration
Timeout for app-server sync reads.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stallTimeout Duration
Stall timeout based on event inactivity.
final
threadSandbox String?
Thread sandbox setting passed through to the runner.
final
turnSandboxPolicy String?
Turn sandbox setting passed through to the runner.
final
turnTimeout Duration
Total timeout for a turn.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited