PollingWorkflowConfig class

Polling scheduler config.

Constructors

PollingWorkflowConfig({required Duration interval})
Creates polling config.
const
PollingWorkflowConfig.fromMap(Map<String, dynamic> map)
Builds polling config from a map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interval Duration
Scheduler poll interval.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited