ServerWorkflowConfig class

Optional local server extension config.

Constructors

ServerWorkflowConfig({required int? port})
Creates server workflow config.
const
ServerWorkflowConfig.fromMap(Map<String, dynamic> map)
Builds server config from a map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
port int?
Optional local server port.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited