WorkspaceWorkflowConfig class

Per-issue workspace config.

Constructors

WorkspaceWorkflowConfig({required String root})
Creates workspace config.
const
WorkspaceWorkflowConfig.fromMap(Map<String, dynamic> map, {required String workflowDirectory, required Map<String, String> environment})
Builds workspace config from a map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
root String
Normalized absolute workspace root.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited