WorkflowException class

Exception thrown when workflow loading or validation fails.

Implemented types

Constructors

WorkflowException(WorkflowFailureCode code, String message)
Creates a workflow exception.
const

Properties

code WorkflowFailureCode
Machine-readable failure code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable failure message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited