WorkflowFailureCode enum

Failure codes for loading and validating a Spectra workflow.

Inheritance
Available extensions

Values

missingWorkflowFile → const WorkflowFailureCode

The workflow file could not be found.

workflowParseError → const WorkflowFailureCode

The workflow file could not be parsed.

workflowFrontMatterNotMap → const WorkflowFailureCode

YAML front matter was present but did not decode to a map.

templateParseError → const WorkflowFailureCode

A workflow template could not be parsed.

templateRenderError → const WorkflowFailureCode

A workflow template could not be rendered.

configValidationError → const WorkflowFailureCode

The workflow config is missing required dispatch settings.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WorkflowFailureCode>
A constant List of the values in this enum, in order of their declaration.