createdNow property
True when this workspace was created during the current call.
Used to gate after_create hook execution.
Implementation
final bool createdNow;
True when this workspace was created during the current call.
Used to gate after_create hook execution.
final bool createdNow;