WorkspaceFailureCode enum

Failure codes for workspace operations.

Inheritance
Available extensions

Values

pathEscape → const WorkspaceFailureCode

Workspace path resolved outside the configured root.

emptyKey → const WorkspaceFailureCode

Workspace key was empty after sanitization.

createFailed → const WorkspaceFailureCode

Workspace directory could not be created.

worktreeAddFailed → const WorkspaceFailureCode

git worktree add failed.

worktreeRemoveFailed → const WorkspaceFailureCode

git worktree remove failed.

hookFailed → const WorkspaceFailureCode

A workspace lifecycle hook reported a non-zero exit.

hookTimedOut → const WorkspaceFailureCode

A workspace lifecycle hook timed out before completing.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WorkspaceFailureCode>
A constant List of the values in this enum, in order of their declaration.