repositoryRoot property
Repository root used as the source for git worktrees. Defaults to the current working directory.
Implementation
final String repositoryRoot;
Repository root used as the source for git worktrees. Defaults to the current working directory.
final String repositoryRoot;