preferredProvider property
Legacy: Preferred provider when no specific usage type is specified. For backward compatibility only.
Implementation
final String? preferredProvider;
Legacy: Preferred provider when no specific usage type is specified. For backward compatibility only.
final String? preferredProvider;