stuckThreshold property
Duration after which an idle agent working on a task is considered stuck.
Implementation
final Duration stuckThreshold;
Duration after which an idle agent working on a task is considered stuck.
final Duration stuckThreshold;