RetryEntry class
Snapshot of a queued retry.
Constructors
Properties
- attempt → int
-
1-based retry attempt number.
final
- dueAt → DateTime
-
Wall-clock time when the retry should fire.
final
- error → String?
-
Optional error message captured when the retry was scheduled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Best-effort human identifier.
final
- issueId → String
-
Issue id the retry is for.
final
- kind → RetryKind
-
Whether this is a continuation or failure retry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timer → Timer?
-
Active timer handle. May be null in unit tests.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON view used by snapshots.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited