RunAttemptStatus class
Snapshot of one attempt at a point in time.
Constructors
- RunAttemptStatus({required String runId, required String issueId, required String issueIdentifier, required int attempt, required RunAttemptPhase phase, required String workspacePath, required DateTime startedAt, String? error})
-
Creates a snapshot.
const
Properties
- attempt → int
-
1-based attempt number (1 for first run).
final
- error → String?
-
Optional human-readable error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issueId → String
-
Issue id this attempt belongs to.
final
- issueIdentifier → String
-
Human-readable issue identifier.
final
- phase → RunAttemptPhase
-
Current phase.
final
- runId → String
-
Stable run identifier (
<issue_id>-<attempt>).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
Wall-clock start time.
final
- workspacePath → String
-
Workspace path used by the attempt.
final
Methods
-
copyWith(
{RunAttemptPhase? phase, String? error}) → RunAttemptStatus - Returns a copy with a new phase or error.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON view used by snapshots and logs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited