AgentRunRequest class
Inputs handed to an AgentRunner for a single attempt.
Constructors
Properties
- attempt → int?
-
Attempt number (
nullon first run,>=1for retry/continuation).final - hashCode → int
-
The hash code for this object.
no setterinherited
- issue → Issue
-
Issue being worked on.
final
- maxTurns → int
-
Maximum number of turns the runner is allowed to take.
final
- renderedPrompt → String
-
Rendered prompt template (Markdown body of
WORKFLOW.md).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workspace → Workspace
-
Workspace prepared by WorkspaceManager.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited