fetchStatesByIds abstract method
Returns minimal normalized issues for the supplied issueIds.
Used by reconciliation. Implementations MAY return a subset when issues no longer exist, and SHOULD include enough state for the scheduler to classify the issue (state, identifier, blockers when relevant).
Implementation
Future<TrackerResult<List<Issue>>> fetchStatesByIds(List<String> issueIds);