TrackerSuccess<T> class
Successful tracker result.
- Inheritance
-
- Object
- TrackerResult<
T> - TrackerSuccess
Constructors
- TrackerSuccess(T value)
-
Creates a successful result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
Returns true when the result is a TrackerError.
no setterinherited
- isSuccess → bool
-
Returns true when the result is a TrackerSuccess.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
Successful value.
final
Methods
-
fold<
R> (R onFailure(TrackerFailure failure), R onSuccess(T value)) → R -
Folds the result into a single value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited