AgentWorkflowConfig class
Agent scheduling config.
Constructors
-
AgentWorkflowConfig({required int maxConcurrentAgents, required int maxTurns, required Duration maxRetryBackoff, required Map<
String, int> maxConcurrentAgentsByState, required String runner, required LlmRunnerWorkflowConfig llm}) -
Creates agent workflow config.
const
-
AgentWorkflowConfig.fromMap(Map<
String, dynamic> map) -
Builds agent config from a map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- llm → LlmRunnerWorkflowConfig
-
LLM-runner-specific overrides.
final
- maxConcurrentAgents → int
-
Maximum number of concurrent agent runs.
final
-
maxConcurrentAgentsByState
→ Map<
String, int> -
Optional per-tracker-state concurrency overrides.
final
- maxRetryBackoff → Duration
-
Maximum retry backoff duration.
final
- maxTurns → int
-
Maximum turns per worker session.
final
- runner → String
-
Identifier for the agent runner implementation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited