HooksWorkflowConfig class
Workspace lifecycle hook config.
Constructors
-
HooksWorkflowConfig({required String? afterCreate, required String? beforeRun, required String? afterRun, required String? beforeRemove, required Duration timeout, String? shellExecutable, List<
String> ? shellArguments}) -
Creates hook config.
const
-
HooksWorkflowConfig.fromMap(Map<
String, dynamic> map) -
Builds hook config from a map.
factory
Properties
- afterCreate → String?
-
Script run after a workspace is first created.
final
- afterRun → String?
-
Script run after each agent attempt.
final
- beforeRemove → String?
-
Script run before workspace removal.
final
- beforeRun → String?
-
Script run before each agent attempt.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shellArguments
→ List<
String> ? -
Optional shell arguments preceding the hook script. When
null, the runtime picks defaults that match shellExecutable (['-lc', script]forbash,['/c', script]forcmd.exe).final - shellExecutable → String?
-
Optional shell executable used to run hook scripts. When
null, the runtime picks a platform-appropriate default (bashon POSIX,cmd.exeon Windows).final - timeout → Duration
-
Timeout applied to hook execution.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited