TrackerWorkflowConfig class
Issue tracker settings from workflow front matter.
Constructors
-
TrackerWorkflowConfig({required String? kind, required String endpoint, required String? apiKey, required String? projectSlug, required List<
String> activeStates, required List<String> terminalStates}) -
Creates tracker workflow config.
const
-
TrackerWorkflowConfig.fromMap(Map<
String, dynamic> map, {required Map<String, String> environment}) -
Builds tracker config from a map.
factory
Properties
-
activeStates
→ List<
String> -
Tracker states eligible for dispatch.
final
- apiKey → String?
-
Resolved tracker API key.
final
- endpoint → String
-
Tracker API endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Tracker kind. Defaults to
local_plan;linearis also supported.final - projectSlug → String?
-
Tracker project slug used to select candidate work.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
terminalStates
→ List<
String> -
Tracker states considered terminal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited