WorkflowLoader class
Loads and parses repository-owned workflow policy.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
{String? path}) → Future< WorkflowDefinition> -
Loads a workflow from
path, defaulting toWORKFLOW.md. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String content, {String path = defaultWorkflowPath}) → WorkflowDefinition - Parses workflow file contents.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultWorkflowPath → const String
- Default workflow file name.