WorkflowReload class
Result delivered to the watcher subscriber.
Constructors
- WorkflowReload({required WorkflowDefinition definition, required WorkflowConfig config, WorkflowException? error})
-
Creates a reload payload.
const
Properties
- config → WorkflowConfig
-
Latest known-good config. Stays at the previous value when the reload
failed.
final
- definition → WorkflowDefinition
-
Latest known-good definition. Stays at the previous value when the
reload failed.
final
- error → WorkflowException?
-
Optional error captured during the reload.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited