WorkspaceHookOutcome class
Outcome of a hook execution.
Constructors
- WorkspaceHookOutcome({required WorkspaceHookKind kind, required bool succeeded, required bool timedOut, required int? exitCode, required String output})
-
Creates an outcome.
const
Properties
- exitCode → int?
-
Exit code, when known.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFatal → bool
-
Whether this hook outcome should fail the current workspace operation.
no setter
- kind → WorkspaceHookKind
-
Hook that ran.
final
- output → String
-
Truncated combined stdout/stderr for observability.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- succeeded → bool
-
Whether the hook completed successfully (exit code 0, no timeout).
final
- timedOut → bool
-
True when the hook exceeded the configured timeout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited