WorkspaceRemoval class
Result of a workspace removal request.
Constructors
- WorkspaceRemoval({required bool removed, required bool worktreeRemoved, WorkspaceHookOutcome? beforeRemoveHook})
-
Creates a removal report.
const
Properties
- beforeRemoveHook → WorkspaceHookOutcome?
-
Outcome of the
before_removehook, when configured.final - hashCode → int
-
The hash code for this object.
no setterinherited
- removed → bool
-
Whether the workspace directory was removed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worktreeRemoved → bool
-
Whether the worktree itself was unregistered with git.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited