SpectraConfig class
Constructors
- SpectraConfig({String? geminiKey, String? openaiKey, String? claudeKey, String? grokKey, String? deepseekKey, String? geminiModel, String? openaiModel, String? claudeModel, String? grokModel, String? deepseekModel, String? preferredProvider, String? planningProvider, String? codingProvider, String? executionMode})
-
SpectraConfig.fromMap(Map<
String, String> map) -
Creates a SpectraConfig from a map (used for secure storage).
factory
- SpectraConfig.fromYaml(Map yaml)
-
factory
Properties
- claudeKey → String?
-
final
- claudeModel → String?
-
final
- codingProvider → String?
-
Provider to use for code generation and implementation tasks.
Examples: executing tasks, writing files, worker agents.
Recommended: Gemini Flash (fastest), DeepSeek (code-focused), GPT-5 Mini.
final
- deepseekKey → String?
-
final
- deepseekModel → String?
-
final
- executionMode → String?
-
Execution mode: how tasks should be executed.
final
- geminiKey → String?
-
final
- geminiModel → String?
-
final
- grokKey → String?
-
final
- grokModel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- openaiKey → String?
-
final
- openaiModel → String?
-
final
- planningProvider → String?
-
Provider to use for planning, documentation, and analysis tasks.
Examples: breaking roadmaps into tasks, analyzing codebases.
Recommended: Claude (reasoning), GPT-5 (balanced), Gemini Pro (fast).
final
- preferredProvider → String?
-
Legacy: Preferred provider when no specific usage type is specified.
For backward compatibility only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? geminiKey, String? openaiKey, String? claudeKey, String? grokKey, String? deepseekKey, String? geminiModel, String? openaiModel, String? claudeModel, String? grokModel, String? deepseekModel, String? preferredProvider, String? planningProvider, String? codingProvider, String? executionMode}) → SpectraConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, String> - Converts to a map (used for secure storage).
-
toString(
) → String -
A string representation of this object.
inherited
-
toYaml(
) → Map< String, String?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited