DashboardService class

Service that runs a local web dashboard for monitoring agents.

Uses Jaspr for server-side component rendering with shelf for HTTP handling. See: https://docs.jaspr.site/going_further/backend

Constructors

DashboardService({required Logger logger, int port = 3000})

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Starts the dashboard HTTP server.
stop() Future<void>
Stops the dashboard server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited