OrchestratorConfig class
Configuration for the orchestrator.
Constructors
Properties
- agentStepTimeout → Duration
-
Timeout for individual agent steps.
final
- enableStuckRecovery → bool
-
Whether to enable automatic stuck agent recovery.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loopDelay → Duration
-
Delay between orchestrator loop iterations.
final
- maxConsecutiveFailures → int
-
Maximum consecutive failures before an agent is marked as failed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stuckThreshold → Duration
-
Duration after which an idle agent working on a task is considered stuck.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited